==> BEQI2_1.0-0.tar.gz: BEQI2/inst/doc/BEQI2.R <==

## ----ini, echo=FALSE, results='hide', message=FALSE----------------------
library(BEQI2)
library(knitr)
library(xtable)


## ----echo=FALSE----------------------------------------------------------
opts_chunk$set(
    echo = FALSE,
    comment = NA,
    quiet = TRUE,
    progress = FALSE,
    tidy = FALSE,
    cache = FALSE,
    message = FALSE,
    error = TRUE,
    warning = TRUE
)


## ----eval=FALSE, echo=TRUE-----------------------------------------------
## BEQI2dir()


## ----eval=FALSE, echo=TRUE-----------------------------------------------
## BEQI2dir(path = "c:/myprojects/BEQI2/BEQI2_FILES")


## ----eval=FALSE, echo=TRUE-----------------------------------------------
## BEQI2()


## ----eval=FALSE, echo=TRUE-----------------------------------------------
## BEQI2(filename = "c:/myprojects/BEQI2/BEQI2_FILES/settings.json")


## ----echo=FALSE, results='asis'------------------------------------------
cat(
    paste(
        readLines(system.file("extdata", "settings.json", package = "BEQI2")), 
        collapse = "\n"
    )
)


## ----echo=FALSE, results='asis'------------------------------------------
d <- scan(
    file = "./tables/tabbeqi2input.csv", 
    what = character(), 
    sep = ",",
    quiet = TRUE
)
h <- d[1:3]
d <- as.data.frame(matrix(data = d[-(1:3)], ncol = 3, byrow = TRUE))
colnames(d) <- h
print(
    xtable(x = d, align = "llp{50mm}p{50mm}"), 
    include.rownames = FALSE, 
    size = "footnotesize",
    add.to.row = list(list(-1), "\\rowcolor{blue!15}")
)


## ----echo=FALSE, results='asis'------------------------------------------
d <- readAMBI()
print(
    xtable(x = d[sample.int(n = nrow(d), size = 25), ], align = "llr"), 
    include.rownames = FALSE,
    size = "footnotesize",
    add.to.row = list(list(-1), "\\rowcolor{blue!15}")
)


## ----echo=FALSE, results='asis'------------------------------------------
d <- readITI(
    filename = system.file("extdata", "REF-FILES", "ITI.csv", 
        package = "BEQI2")
)
print(
    xtable(x = d[sample.int(n = nrow(d), size = 30), ], align = "llr"), 
    include.rownames = FALSE,
    size = "footnotesize",
    add.to.row = list(list(-1), "\\rowcolor{blue!15}")
)


## ----echo=FALSE, results='asis'------------------------------------------
d <- data.frame(
    ITI = c( "I", "II", "III", "IV"),
    description = c(
        "Suspension feeders",
        "Interface feeders",
        "Surface deposit feeders",
        "Subsurface deposit feeders"
    )
)
print(
    xtable(x = d, align = "lrl"), 
    include.rownames = FALSE,
    size = "footnotesize",
    add.to.row = list(list(-1), "\\rowcolor{blue!15}")
)


## ----echo=FALSE, results='asis'------------------------------------------
filename <- system.file(
    "extdata", "REF-FILES", "BEQI2-Ecotopes-2014-04-11.csv", 
    package = "BEQI2"
)
d <- read.csv(file = filename)
d$LITAREA <- NULL
d$LITREFS <- NULL
d$OMSVG <- NULL
print(
    xtable(x = d), 
    include.rownames = FALSE,
    size = "footnotesize",
    add.to.row = list(list(-1), "\\rowcolor{blue!15}"),
    sanitize.text.function = function(x) {
        gsub(pattern="_", replacement = "\\\\_", x=x)
    },
    rotate.colnames = TRUE
)

==> BEQI2_1.0-1.tar.gz: BEQI2/inst/doc/BEQI2.R <==
## ----ini, echo=FALSE, results='hide', message=FALSE----------------------
library(BEQI2)
library(knitr)
library(xtable)

## ----echo=FALSE----------------------------------------------------------
opts_chunk$set(
    echo = FALSE,
    comment = NA,
    quiet = TRUE,
    progress = FALSE,
    tidy = FALSE,
    cache = FALSE,
    message = FALSE,
    error = TRUE,
    warning = TRUE
)

## ----eval=FALSE, echo=TRUE-----------------------------------------------
#  BEQI2dir()

## ----eval=FALSE, echo=TRUE-----------------------------------------------
#  BEQI2dir(path = "c:/myprojects/BEQI2/BEQI2_FILES")

## ----eval=FALSE, echo=TRUE-----------------------------------------------
#  BEQI2()

## ----eval=FALSE, echo=TRUE-----------------------------------------------
#  BEQI2(filename = "c:/myprojects/BEQI2/BEQI2_FILES/settings.json")

## ----echo=FALSE, results='asis'------------------------------------------
cat(
    paste(
        readLines(system.file("extdata", "settings.json", package = "BEQI2")), 
        collapse = "\n"
    )
)

## ----echo=FALSE, results='asis'------------------------------------------
d <- scan(
    file = "./tables/tabbeqi2input.csv", 
    what = character(), 
    sep = ",",
    quiet = TRUE
)
h <- d[1:3]
d <- as.data.frame(matrix(data = d[-(1:3)], ncol = 3, byrow = TRUE))
colnames(d) <- h
print(
    xtable(x = d, align = "llp{50mm}p{50mm}"), 
    include.rownames = FALSE, 
    size = "footnotesize",
    add.to.row = list(list(-1), "\\rowcolor{blue!15}")
)

## ----echo=FALSE, results='asis'------------------------------------------
d <- readAMBI()
print(
    xtable(x = d[sample.int(n = nrow(d), size = 25), ], align = "llr"), 
    include.rownames = FALSE,
    size = "footnotesize",
    add.to.row = list(list(-1), "\\rowcolor{blue!15}")
)

## ----echo=FALSE, results='asis'------------------------------------------
d <- readITI(
    filename = system.file("extdata", "REF-FILES", "ITI.csv", 
        package = "BEQI2")
)
print(
    xtable(x = d[sample.int(n = nrow(d), size = 30), ], align = "llr"), 
    include.rownames = FALSE,
    size = "footnotesize",
    add.to.row = list(list(-1), "\\rowcolor{blue!15}")
)

## ----echo=FALSE, results='asis'------------------------------------------
d <- data.frame(
    ITI = c( "I", "II", "III", "IV"),
    description = c(
        "Suspension feeders",
        "Interface feeders",
        "Surface deposit feeders",
        "Subsurface deposit feeders"
    )
)
print(
    xtable(x = d, align = "lrl"), 
    include.rownames = FALSE,
    size = "footnotesize",
    add.to.row = list(list(-1), "\\rowcolor{blue!15}")
)

## ----echo=FALSE, results='asis'------------------------------------------
filename <- system.file(
    "extdata", "REF-FILES", "BEQI2-Ecotopes-2014-04-11.csv", 
    package = "BEQI2"
)
d <- read.csv(file = filename)
d$LITAREA <- NULL
d$LITREFS <- NULL
d$OMSVG <- NULL
print(
    xtable(x = d), 
    include.rownames = FALSE,
    size = "footnotesize",
    add.to.row = list(list(-1), "\\rowcolor{blue!15}"),
    sanitize.text.function = function(x) {
        gsub(pattern="_", replacement = "\\\\_", x=x)
    },
    rotate.colnames = TRUE
)
